@@ -10,12 +10,6 @@ import sys
 PATH_PRJ = '/'.join(os.path.abspath(__file__).split('/')[:-2])
 sys.path.append(PATH_PRJ)
 
-## jieba
-
-词性
-import jieba.posseg as pseg
-pairs = list(pseg.lcut('难过'))
-list(list(pseg.lcut('分散'))[0])[1]  # 第一个词的词性
 """
 import ahocorasick
 import csv
